@@ -34,6 +34,7 @@
 #include "statisticsmodel.h"
 #include "keduvoclesson.h"
 #include "utils.h"
+#include "documentsettings.h"
 
 
 // GradeDelegate shows the graphic colored bar in the statistics,
@@ -47,7 +48,7 @@ public:
     }
 
     void paint(QPainter *painter, const QStyleOptionViewItem &option,
-		       const QModelIndex &index) const Q_DECL_OVERRIDE
+               const QModelIndex &index) const Q_DECL_OVERRIDE
     {
         QApplication::style()->drawPrimitive(QStyle::PE_PanelItemViewItem, &option, painter, 0);
 
@@ -57,16 +58,23 @@ public:
         }
 
         // Draw the colored bar.
-        KEduVocContainer *container = index.data(StatisticsModel::Container).value<KEduVocContainer*>();
+        KEduVocContainer *container = index.data(StatisticsModel::Container)
+                                           .value<KEduVocContainer*>();
+        QStringList activeConjugationTenses = index.data(StatisticsModel::ActiveConjugationTenses)
+                                                   .toStringList();
         WordCount  wordCount;
-        wordCount.fillFromContainer(*container, index.column() - ContainerModel::FirstDataColumn);
+        wordCount.fillFromContainerForPracticeMode(
+            *container,
+            index.column() - ContainerModel::FirstDataColumn,
+            activeConjugationTenses
+        );
         ConfidenceColors  colors(ConfidenceColors::ProgressiveColorScheme);
 
         paintColorBar(*painter, option.rect, wordCount, colors); // in utils
 
         // Draw the text telling the percentage on top of the bar.
         painter->drawText(option.rect, Qt::AlignCenter,
-			  QStringLiteral("%1%").arg(index.data(StatisticsModel::TotalPercent).toInt()));
+                    QStringLiteral("%1%").arg(index.data(StatisticsModel::TotalPercent).toInt()));
     }
 };
 
@@ -108,6 +116,11 @@ LessonStatisticsView::LessonStatisticsView(QWidget *parent)
 	    this,     &LessonStatisticsView::sectionResized);
 }
 
+LessonStatisticsView::~LessonStatisticsView()
+{
+    saveExpandedStatus();
+}
+
 void LessonStatisticsView::setModel(ContainerModel *model)
 {
     ContainerView::setModel(model);
@@ -137,8 +150,7 @@ void LessonStatisticsView::sectionResized(int index,
 void LessonStatisticsView::adjustColumnWidths()
 {
     int firstWidth = columnWidth(0) + columnWidth(1);
-    // Subtract 5 here otherwise we get a horizontal scrollbar.
-    int totalWidth = width() - firstWidth - 5;
+    int totalWidth = viewport()->width() - firstWidth;
     int columnCount = model()->columnCount(QModelIndex());
     int visibleColumns = 0;
     for (int i = ContainerModel::FirstDataColumn; i < columnCount; ++i) {
@@ -167,3 +179,76 @@ void LessonStatisticsView::removeGradesChildren()
     KEduVocLesson *lesson = static_cast<KEduVocLesson*>(selectedIndex.internalPointer());
     lesson->resetGrades(-1, KEduVocContainer::Recursive);
 }
+
+void LessonStatisticsView::saveExpandedStatus() const
+{
+    auto statisticsModel = qobject_cast<StatisticsModel *>(model());
+    Q_ASSERT(statisticsModel != nullptr);
+
+    QStringList collapsedItems;
+    getCollapsedItems(collapsedItems, statisticsModel->index(0, 0, QModelIndex()), QString());
+
+    const KEduVocDocument *doc = statisticsModel->document();
+    if (doc != nullptr) {
+        DocumentSettings documentSettings(doc->url().url());
+        documentSettings.setCollapsedStatisticsViewItems(collapsedItems);
+        documentSettings.save();
+    }
+}
+
+void LessonStatisticsView::getCollapsedItems(QStringList &collapsedItems, const QModelIndex &item,
+                                            QString name) const
+{
+    if (!item.isValid()) {
+        return;
+    }
+
+    int rowCount = model()->rowCount(item);
+    if (rowCount > 0) {
+        // Item has children and therefore expandable
+        name += item.data().toString();
+        if (!isExpanded(item)) {
+            collapsedItems << name;
+        }
+        for (int row = 0; row < rowCount; ++row) {
+            getCollapsedItems(collapsedItems, model()->index(row, 0, item), name + '/');
+        }
+    }
+}
+
+void LessonStatisticsView::restoreExpandedStatus()
+{
+    auto statisticsModel = qobject_cast<StatisticsModel *>(model());
+    Q_ASSERT(statisticsModel != nullptr);
+
+    const KEduVocDocument *doc = statisticsModel->document();
+    if (doc != nullptr) {
+        DocumentSettings documentSettings(doc->url().url());
+        documentSettings.load();
+        QStringList collapsedItems = documentSettings.collapsedStatisticsViewItems();
+        setCollapsedItems(collapsedItems, statisticsModel->index(0, 0, QModelIndex()), QString());
+    }
+}
+
+void LessonStatisticsView::setCollapsedItems(const QStringList &collapsedItems,
+                                             const QModelIndex &item, QString name)
+{
+    if (!item.isValid()) {
+        return;
+    }
+
+    int rowCount = model()->rowCount(item);
+    if (rowCount > 0) {
+        // Item has children and therefore expandable
+        name += item.data().toString();
+        if (collapsedItems.contains(name)) {
+            collapse(item);
+        } else {
+            expand(item);
+        }
+        for (int row = 0; row < rowCount; ++row) {
+            setCollapsedItems(collapsedItems, model()->index(row, 0, item), name + '/');
+        }
+    }
+}
+
